@@ -634,7 +634,7 @@ def detect_lines(s, tapers, p=None, **taper_kws):
     # spectra is (n_arr, K, nfft)
     spectra = tapered_spectra(s, tapers, **taper_kws)
     nfft = spectra.shape[-1]
-    spectra = spectra[...,:nfft/2 + 1]
+    spectra = spectra[..., :nfft//2 + 1]
 
     # Set up some data for the following calculations --
     #   get the DC component of the taper spectra
@@ -1930,50 +1930,17 @@ def fir_design_matrix(events, len_hrf):
     fir_matrix = np.zeros((events.shape[0], len_hrf * event_types.shape[0]))
 
     for t in event_types:
-        idx_h_a = np.where(event_types == t)[0] * len_hrf
+        idx_h_a = (np.array(np.where(event_types == t)[0]) * len_hrf)[0]
         idx_h_b = idx_h_a + len_hrf
         idx_v = np.where(events == t)[0]
         for idx_v_a in idx_v:
             idx_v_b = idx_v_a + len_hrf
             fir_matrix[idx_v_a:idx_v_b, idx_h_a:idx_h_b] += (np.eye(len_hrf) *
-                                                            np.sign(t))
+                                                             np.sign(t))
 
     return fir_matrix
 
 
-#We carry around a copy of the hilbert transform analytic signal from newer
-#versions of scipy, in case someone is using an older version of scipy with a
-#borked hilbert:
-def hilbert_from_new_scipy(x, N=None, axis=-1):
-    """This is a verbatim copy of scipy.signal.hilbert from scipy version
-    0.8dev, which we carry around in order to use in case the version of scipy
-    installed is old enough to have a broken implementation of hilbert """
-
-    x = np.asarray(x)
-    if N is None:
-        N = x.shape[axis]
-    if N <= 0:
-        raise ValueError("N must be positive.")
-    if np.iscomplexobj(x):
-        print("Warning: imaginary part of x ignored.")
-        x = np.real(x)
-    Xf = fftpack.fft(x, N, axis=axis)
-    h = np.zeros(N)
-    if N % 2 == 0:
-        h[0] = h[N / 2] = 1
-        h[1:N / 2] = 2
-    else:
-        h[0] = 1
-        h[1:(N + 1) / 2] = 2
-
-    if len(x.shape) > 1:
-        ind = [np.newaxis] * x.ndim
-        ind[axis] = slice(None)
-        h = h[ind]
-    x = fftpack.ifft(Xf * h, axis=axis)
-    return x
-
-
 #---------- MAR utilities ----------------------------------------
 
 # These utilities are used in the computation of multivariate autoregressive
