@@ -1,9 +1,8 @@
 """nitime version/release information"""
-from nitime.six.moves import map
 
 # Format expected by setup.py and doc/source/conf.py: string of form "X.Y.Z"
 _version_major = 0
-_version_minor = 6
+_version_minor = 7
 _version_micro = ''  # use '' for first of series, number for 1 and above
 #_version_extra = 'dev'
 _version_extra = ''  # Uncomment this for full releases
@@ -95,15 +94,6 @@ MAJOR = _version_major
 MINOR = _version_minor
 MICRO = _version_micro
 VERSION = __version__
-PACKAGES = ['nitime',
-            'nitime.tests',
-            'nitime.fmri',
-            'nitime.fmri.tests',
-            'nitime.algorithms',
-            'nitime.algorithms.tests',
-            'nitime.analysis',
-            'nitime.analysis.tests',
-            ]
 PACKAGE_DATA = {"nitime": ["LICENSE", "tests/*.txt", "tests/*.npy",
                                   "data/*.nii.gz","data/*.txt", "data/*.csv"]}
 REQUIRES = ["numpy", "matplotlib", "scipy"]
